@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.0900';
+our $VERSION = '0.0901';
 
 use strict;
 use warnings;
@@ -228,7 +228,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.0900
+version 0.0901
 
 =head1 SYNOPSIS
 
@@ -260,9 +260,9 @@ Nothing is exported by default.
 
 =head2 setup_score
 
-  $score = MIDI::Util::setup_score;  # Use defaults
+  $score = setup_score;  # Use defaults
 
-  $score = MIDI::Util::setup_score(  # Override defaults
+  $score = setup_score(  # Override defaults
     lead_in   => $beats,
     volume    => $volume,
     bpm       => $bpm,
@@ -288,9 +288,9 @@ Named parameters and defaults:
 
 =head2 set_chan_patch
 
-  MIDI::Util::set_chan_patch( $score, $channel );  # Just set the channel
+  set_chan_patch( $score, $channel );  # Just set the channel
 
-  MIDI::Util::set_chan_patch( $score, $channel, $patch );
+  set_chan_patch( $score, $channel, $patch );
 
 Set the MIDI channel and patch.
 
@@ -302,7 +302,7 @@ Positional parameters and defaults:
 
 =head2 midi_dump
 
-  $dump = MIDI::Util::midi_dump($list_name);
+  $dump = midi_dump($list_name);
 
 Return sorted array references of the following L<MIDI>,
 L<MIDI::Simple>, and L<MIDI::Event> internal lists:
@@ -325,14 +325,14 @@ L<MIDI::Simple>, and L<MIDI::Event> internal lists:
 
 =head2 midi_format
 
-  @formatted = MIDI::Util::midi_format(@notes);
+  @formatted = midi_format(@notes);
 
 Change sharp C<#> and flat C<b>, in the list of named notes, to the
 L<MIDI::Simple> C<s> and C<f> respectively.
 
 =head2 set_time_sig
 
-  MIDI::Util::set_time_sig( $score, $signature );
+  set_time_sig( $score, $signature );
 
 Set the B<score> C<time_signature> based on the given string.
 
